@@ -2,7 +2,7 @@
 import sys
 import os
 
-from importlib import import_module, resources as importlib_resources
+from importlib import resources as importlib_resources
 import shutil
 import subprocess
 
@@ -57,13 +57,15 @@ def read_config():
     logging.info(f"Read project configuration")
     from mlops_settings import model_names, model_files, model_req_files
     from mlops_settings import model_artifact_folders, infos, model_test_files
+    from mlops_settings import model_platforms
     return zip(
         model_names, 
         model_files, 
         model_req_files, 
         model_artifact_folders,
         infos,
-        model_test_files
+        model_test_files,
+        model_platforms
     )
 
 
